---
id: 102
properties:
- id: priority
  name: testy
  type: string
  value: ''
- id: done
  name: Done
  type: boolean
  value: false
- id: status
  name: Status
  type: status
  value: Not Started
---

The kitchen faucet drips when turned off. Probably needs a new washer.

## Steps

1. Turn off water supply
2. Remove handle
3. Replace washer
4. Reassemble